<?php
/**
* Plugin Name: Home Filter
* Description: A filter for the home posts
* Version: 1.0
* Author: Alejandro Torres
*/

class homeFilter {

  var $hf_options;

  public function __construct() {

    $this->hf_options = get_option( 'hf_settings' ); // Saving options

    // STYLES
    add_action( 'wp_enqueue_scripts', array($this,'stylesScripts' ));

    // SHORTCODE
    add_shortcode( "home-filter", array($this,"print_code"));

    // AJAX Handlers
		add_action( 'wp_ajax_show_filter', array( $this, 'show_filter' ));
		add_action( 'wp_ajax_nopriv_show_filter', array( $this, 'show_filter' ));

    // Register taxonomies
    add_action( 'init', array( $this, 'register_taxonomies'));

    /************ BACKEND ***************/
    add_action( 'admin_menu', array( $this, 'hf_add_admin_menu' ));
    add_action( 'admin_init', array( $this, 'hf_settings_init' ));

  }

  public function stylesScripts() {

    // STYLES
    wp_enqueue_style( 'home-filter', plugin_dir_url( __FILE__ ) . "css/style.css", array(), time() );

    // SCRIPTS
    wp_register_script( 'show-filter', plugin_dir_url( __FILE__ ) . 'js/script.js', array('jquery'), '', true );

    wp_localize_script( 'show-filter', 'S_Filter', array(
      // URL to wp-admin/admin-ajax.php to process the request

      'ajaxurl' => admin_url( 'admin-ajax.php' ),

      // generate a nonce with a unique ID "myajax-post-comment-nonce"
      // so that you can check it later when an AJAX request is sent
      'security' => wp_create_nonce( 'show-filter-ajax' ),

    ));

  }

  // SHORTCODE Code
  public function print_code() {

  wp_enqueue_script( 'show-filter' );
  ?>

    <div class="up-pagination"></div>

    <!-- FILTER HEADER -->
    <div class="hf-header">

      <div class="container">

        <ul class="nav nav-tabs tabs-hf">
          <li class="active">
            <a href="#cat-emocionales" data-toggle="tab">
              <img src="<?php echo plugins_url( 'imgs/smiley.png', __FILE__ ); ?>">
              <div class="header-big"><?php _e("¿Qué necesitas hoy?"); ?></div>
              <div class="header-small"><?php _e("Cuéntanos cómo te sientes y te alegramos el día"); ?></div>
            </a>
          </li>
          <li>
            <a href="#cat-normales" data-toggle="tab">
              <img src="<?php echo plugins_url( 'imgs/binoculares.png', __FILE__ ); ?>">
              <div class="header-big"><?php _e("¿Qué buscas?"); ?></div>
              <div class="header-small"><?php _e("Una forma más clásica de encontrar lo que quieres"); ?></div>
            </a>
          </li>
        </ul>

      </div>

    </div>

    <!-- FILTER BODY -->
    <div class="hf-wrapper">

      <div class="container">

        <div class="tab-content">

          <div id="cat-emocionales" class="tab-pane fade in active">
            <?php $this->tags_filter('categorias_emocionales'); ?>
          </div>

          <div id="cat-normales" class="tab-pane fade">
            <?php $this->tags_filter('category'); ?>
          </div>

        </div>

      </div>

    </div>


    <!-- FILTER RESULTS -->
    <div class="hf-results">

      <div class="container">

        <div class="row hf-results-row">

          <!-- PRINTING THE RESULTS HERE -->
          <?php $this->loop_filter('','',''); ?>

        </div>

      </div>

    </div>

  <?php
  }

  // Showing the tags of the filter. It requires the name of the category as argument
  public function tags_filter($cat_name) {

    $terms = get_terms( $cat_name, array (
          'hide_empty' => true
    ) );

    // Checking that there are terms in the category, and printing them
    if($terms) {

      // List in mobile
      echo "<div class='hf-terms-select'>";
      echo "<select>";
      echo "<option value=''>Todas</option>";
      foreach ( $terms as $term ) {

        echo "<option value='".$term->term_id."'>".$term->name."</option>";

      }
      echo "</select>";
      echo "</div>";

      // List in desktop
      echo "<ul class='hf-terms-list'>";
      echo "<li><a class='active'>Todas</a></li>";
      foreach ( $terms as $term ) {

        echo "<li><a data-cat='".$term->term_id."'>".$term->name."</a></li>";

      }

      echo "</ul>";

    } else {

      _e("Lo sentimos, no hay términos en la categoría seleccionada.");

    }

  }

  // AJAX answer to the filter buttons
  public function show_filter() {

    check_ajax_referer( 'show-filter-ajax', 'security' );

    $this->loop_filter($_POST['term_code'],$_POST['term_cat'], $_POST['paged']);

    die();
  }

  // Query retrieving the posts
  public function loop_filter($codeterm,$term_cat,$paged) {

    if($this->hf_options['hf_select_field_0']=="3-cols") {
      $postspp = 6;
    }
    if($this->hf_options['hf_select_field_0']=="2-3-2-cols") {
      $postspp = 5;
    }

    if($codeterm!='') {
      $args = array (
        'showposts' => $postspp,
        'paged' => $paged,
        'tax_query' => array(
          array(
            'taxonomy' => $term_cat,
            'field' => 'term_id',
            'terms' => $codeterm
          )
        ),
        'post_status' => 'publish'
      );
    } else {
      $args = array (
        'showposts' => $postspp,
        'paged' => $paged,
        'post_status' => 'publish'
      );
    }



    $query = new WP_Query( $args );

    if( $query->have_posts() ) :
      $i=1;
      $j=1;
      $k=1;
      // Printing the posts
      while( $query->have_posts()) {
        $query->the_post();

        /************** 3 COLUMNS *****************/
        if($this->hf_options['hf_select_field_0']=="3-cols") {
        ?>
          <div class="col-xs-12 col-sm-6 col-md-4 hf-post">
            <?php
            if ( has_post_thumbnail( $_post->ID ) ) {

                $featured_image = get_the_post_thumbnail( $_post->ID, 'full' );

            } else {

              $featured_image = "<img src='".get_template_directory_uri()."/imgs/placeholder-gray-icon.jpg' alt='Placeholder en gris'>";

            }
            echo "<div class='hf-post-img'>".$featured_image."</div>";
            echo "<div class='hf-post-content'><h5>".get_the_title()."</h5>".get_the_excerpt()."<br><a href='".get_permalink(get_the_id())."' class='mod_bot-button style2'>".__("Leer más")."</a><div class='sect-corner'><img src='".get_template_directory_uri()."/imgs/corner.png' alt='Esquina doblada'></div></div>";
            ?>
          </div>
          <?php
          if($i%3==0) {
            echo "<div class='clearfix visible-md visible-lg'></div>";
          }
          if($i%2==0) {
            echo "<div class='clearfix visible-sm'></div>";
          }
          echo "<div class='clearfix visible-sm'></div>";
          ?>
        <?php
        }

        /****************** 2-3-2 COLUMNS *******************/
        if($this->hf_options['hf_select_field_0']=="2-3-2-cols") {
          if($k%2==1) { ?>
          <div class="col-xs-12 col-sm-6 col-md-6 hf-post">
          <?php } else { ?>
          <div class="col-xs-12 col-sm-6 col-md-4 hf-post">
          <?php } ?>
            <?php
            if ( has_post_thumbnail( $_post->ID ) ) {

                $featured_image = get_the_post_thumbnail( $_post->ID, 'full' );

            } else {

              $featured_image = "<img src='".get_template_directory_uri()."/imgs/placeholder-gray-icon.jpg' alt='Placeholder en gris'>";

            }
            echo "<div class='hf-post-img'>".$featured_image."</div>";
            echo "<div class='hf-post-content'><h5>".get_the_title()."</h5>".get_the_excerpt()."<br><a href='".get_permalink(get_the_id())."' class='mod_bot-button style2'>".__("Leer más")."</a><div class='sect-corner'><img src='".get_template_directory_uri()."/imgs/corner.png' alt='Esquina doblada'></div></div>";
            ?>
          </div>
          <?php
          if($k%2==1) {
            if($j==2) {
              $j=0;
              $k++;
              echo "<div class='clearfix visible-md visible-lg visible-sm'></div>";
            }
          } else {
            if($j==3) {
              $j=0;
              $k++;
              echo "<div class='clearfix visible-md visible-lg'></div>";
            }
            if($j==2) {
              echo "<div class='clearfix visible-sm'></div>";
            }
          }
          echo "<div class='clearfix visible-xs'></div>";
          ?>
        <?php
        }
        $i++;
        $j++;

      }

      echo "<div class='clearfix'></div>";

      numeric_pagination($query,$paged);
      wp_reset_postdata();

    else :
      echo "no"; // For Javascript error handling
    endif;
  }

  // Adding new taxonomies to posts
  public function register_taxonomies() {

    register_taxonomy(
  		'categorias_emocionales',
  		'post',
  		array(
  			'label' => __( 'Categorías Emocionales' ),
  			'rewrite' => array( 'slug' => 'categorias-emocionales' ),
  			'hierarchical' => true,
  		)
  	);

  }

  /********************************** BACKEND *************************************/
  public function hf_add_admin_menu(  ) {

  	add_options_page( 'Home Filter', 'Home Filter', 'manage_options', 'home_filter', array($this,'hf_options_page') );

  }

  public function hf_settings_init(  ) {

  	register_setting( 'pluginPage', 'hf_settings' );

  	add_settings_section(
  		'hf_pluginPage_section',
  		__( 'Opciones para el filtro en la Home', 'home-filter' ),
  		array($this,'hf_settings_section_callback'),
  		'pluginPage'
  	);

  	add_settings_field(
  		'hf_select_field_0',
  		__( 'Formato con el que se muestra', 'home-filter' ),
  		array($this,'hf_select_field_0_render'),
  		'pluginPage',
  		'hf_pluginPage_section'
  	);


  }

  public function hf_select_field_0_render(  ) {

  	$this->hf_options = get_option( 'hf_settings' );
  	?>
  	<select name='hf_settings[hf_select_field_0]'>
  		<option value='3-cols' <?php selected( $this->hf_options['hf_select_field_0'], '3-cols' ); ?>>3 columns</option>
  		<option value='2-3-2-cols' <?php selected( $this->hf_options['hf_select_field_0'], '2-3-2-cols' ); ?>>2-3-2 columns</option>
  	</select>

    <?php

  }

  public function hf_settings_section_callback(  ) {

  	echo __( 'Desde aquí se pueden escoger las opciones del filtro de post que se encuentra en la Home.', 'home-filter' );

  }

  public function hf_options_page(  ) {

  	?>
  	<form action='options.php' method='post'>

  		<h2>Home Filter</h2>

  		<?php
  		settings_fields( 'pluginPage' );
  		do_settings_sections( 'pluginPage' );
  		submit_button();
  		?>

  	</form>
  	<?php

  }

}

$hf = new homeFilter();
